import {Gamesystem} from "./gamesystems/Gamesystem";
import {ScriptAccount} from "./scriptAccounts/ScriptAccount";

export class GameModel {
  private readonly _gameModelName: string

  private _gamesystems: Gamesystem[] = [];
  private _scriptAccounts: ScriptAccount[] = [];

  constructor(gameModelName: string) {
    this._gameModelName = gameModelName;
  }
  get gameModelName(): string {
    return this._gameModelName;
  }


  get gamesystems(): Gamesystem[] {
    return this._gamesystems;
  }
  get scriptAccounts(): ScriptAccount[] {
    return this._scriptAccounts;
  }

  addGamesystem(gamesystem: Gamesystem) {
    if(!this.gamesystems.includes(gamesystem)) {
      this._gamesystems.push(gamesystem);
    }
  }

  removeGamesystem(gamesystem : Gamesystem) {
    this._gamesystems = this._gamesystems.filter(g => g !== gamesystem);
  }

  addScriptAccount(scriptAccount: ScriptAccount) {
    if(scriptAccount != undefined && !this.scriptAccounts.includes(scriptAccount)) {
      const searchedScriptAccount = this.scriptAccounts.find(s => s.componentName === scriptAccount.componentName);
      if(searchedScriptAccount == undefined) {
        this.scriptAccounts.push(scriptAccount);
      }
    }
  }

  removeScriptAccount(scriptAccount: ScriptAccount) {
    if(scriptAccount != undefined) {
      this._scriptAccounts = this.scriptAccounts.filter(s => s != scriptAccount);
    }
  }

}
